---
title: <span class="badge builder"></span> ScaleDistributionConfig
---
# <span class="badge builder"></span> ScaleDistributionConfig

## Constructor

```python
ScaleDistributionConfig()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> common.ScaleDistributionConfig
```

### <span class="badge object-method"></span> linear_threshold

```python
def linear_threshold(linear_threshold: float) -> typing.Self
```

### <span class="badge object-method"></span> log

```python
def log(log: float) -> typing.Self
```

### <span class="badge object-method"></span> type_val

```python
def type_val(type_val: common.ScaleDistribution) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [ScaleDistributionConfig](./object-ScaleDistributionConfig.md)
